(function(funcName, baseObj) {
    "use strict";
    // The public function name defaults to window.docReady
    // but you can modify the last line of this function to pass in a different object or method name
    // if you want to put them in a different namespace and those will be used instead of 
    // window.docReady(...)
    funcName = funcName || "docReady";
    baseObj = baseObj || window;
    var readyList = [];
    var readyFired = false;
    var readyEventHandlersInstalled = false;
    
    // call this when the document is ready
    // this function protects itself against being called more than once
    function ready() {
        if (!readyFired) {
            // this must be set to true before we start calling callbacks
            readyFired = true;
            for (var i = 0; i < readyList.length; i++) {
                // if a callback here happens to add new ready handlers,
                // the docReady() function will see that it already fired
                // and will schedule the callback to run right after
                // this event loop finishes so all handlers will still execute
                // in order and no new ones will be added to the readyList
                // while we are processing the list
                readyList[i].fn.call(window, readyList[i].ctx);
            }
            // allow any closures held by these functions to free
            readyList = [];
        }
    }
    
    function readyStateChange() {
        if ( document.readyState === "complete" ) {
            ready();
        }
    }
    
    // This is the one public interface
    // docReady(fn, context);
    // the context argument is optional - if present, it will be passed
    // as an argument to the callback
    baseObj[funcName] = function(callback, context) {
        if (typeof callback !== "function") {
            throw new TypeError("callback for docReady(fn) must be a function");
        }
        // if ready has already fired, then just schedule the callback
        // to fire asynchronously, but right away
        if (readyFired) {
            setTimeout(function() {callback(context);}, 1);
            return;
        } else {
            // add the function and context to the list
            readyList.push({fn: callback, ctx: context});
        }
        // if document already ready to go, schedule the ready function to run
        // IE only safe when readyState is "complete", others safe when readyState is "interactive"
        if (document.readyState === "complete" || (!document.attachEvent && document.readyState === "interactive")) {
            setTimeout(ready, 1);
        } else if (!readyEventHandlersInstalled) {
            // otherwise if we don't have event handlers installed, install them
            if (document.addEventListener) {
                // first choice is DOMContentLoaded event
                document.addEventListener("DOMContentLoaded", ready, false);
                // backup is window load event
                window.addEventListener("load", ready, false);
            } else {
                // must be IE
                document.attachEvent("onreadystatechange", readyStateChange);
                window.attachEvent("onload", ready);
            }
            readyEventHandlersInstalled = true;
        }
    }
})("docReady", window);
// modify this previous line to pass in your own method name 
// and object for the method to be attached to

docReady(function() {
    
    var show_elements = [];
    var hide_elements = [];
    
    var shape_square = document.getElementsByClassName("area-shape-square")[0];
    shape_square.onclick = function(e){
        
        document.getElementsByClassName("area-length")[0].value = "";
        document.getElementsByClassName("area-width")[0].value = "";
        
        show_elements = document.querySelectorAll(".area-length, .area-width");
        for (i = 0; i < show_elements.length; i++) {
            show_elements[i].style.display = 'inline-block';
        }
        
        hide_elements = document.querySelectorAll(".area-diameter, .area-height, .area-widthofbase");
        for (i = 0; i < hide_elements.length; i++) {
            hide_elements[i].style.display = 'none';
        }
        
    }
    
    var shape_circle = document.getElementsByClassName("area-shape-circle")[0];
    shape_circle.onclick = function(e){
        
        document.getElementsByClassName("area-diameter")[0].value = "";
        
        show_elements = document.querySelectorAll(".area-diameter");
        for (i = 0; i < show_elements.length; i++) {
            show_elements[i].style.display = 'inline-block';
        }
        
        hide_elements = document.querySelectorAll(".area-length, .area-width, .area-height, .area-widthofbase");
        for (i = 0; i < hide_elements.length; i++) {
            hide_elements[i].style.display = 'none';
        }
        
    }
    
    var shape_triangle = document.getElementsByClassName("area-shape-triangle")[0];
    shape_triangle.onclick = function(e){
        
        document.getElementsByClassName("area-height")[0].value = "";
        document.getElementsByClassName("area-widthofbase")[0].value = "";
        
        show_elements = document.querySelectorAll(".area-height, .area-widthofbase");
        for (i = 0; i < show_elements.length; i++) {
            show_elements[i].style.display = 'inline-block';
        }
        
        hide_elements = document.querySelectorAll(".area-diameter, .area-width, .area-length");
        for (i = 0; i < hide_elements.length; i++) {
            hide_elements[i].style.display = 'none';
        }
        
    }
    
    //document.querySelectorAll('input[type="number"]')
    //$('input[type=number]').on("keydown", function(event) {
    //    if(!((event.keyCode > 95 && event.keyCode < 106)
    //        || (event.keyCode > 47 && event.keyCode < 58) 
    //        || event.keyCode == 8 || event.keyCode == 46 
    //        || event.keyCode == 37 || event.keyCode == 39
    //        || event.keyCode == 9 || event.keyCode == 190 
    //        )) {
    //        return false;
    //    }
    //});  
    
    document.querySelector(".calculator").addEventListener("submit", function(event){
        		
        event.preventDefault();
        
		$('.calculator-results').fadeOut("slow");
           
		var turf_squared = 0;
        var area_squared = 0;
        var area_cubed = 0;
        
        var shape = $(':radio[name=area-shape-radio]:checked').val();
        var units = $(':radio[name=area-units-radio]:checked').val();
        var length = parseFloat($('.area-length').val());
        var width = parseFloat($('.area-width').val());
        var diameter = parseFloat($('.area-diameter').val());
        var height = parseFloat($('.area-height').val());
        var widthofbase = parseFloat($('.area-widthofbase').val()); 
        var depth = parseFloat($(':radio[name=area-depth-radio]:checked').val());
		var turf_length = 0;
		var turf_width = 0;
		var turf_diameter = 0;
		var turf_height = 0;
		var	turf_widthofbase = 0;
		var area_length = 0;
		var area_width = 0;
		var area_diameter = 0;
		var area_height = 0;
		var	area_widthofbase = 0;
		var area_depth = 0;

        if (units == 'metres') {
            turf_length = length * 1.0936133;
            turf_width = width * 1.0936133;
            turf_diameter = diameter * 1.0936133;                            
            turf_height = height * 1.0936133;
			turf_widthofbase = widthofbase * 1.0936133;
			area_length = length;
            area_width = width; 
			area_diameter = diameter;
			area_height = height;
			area_widthofbase = widthofbase;
            area_depth = (depth == 0 ? 0 : (depth / 39.370)); 
        }

        if (units == 'feet') {
            turf_length = length * 0.333333;
            turf_width = width * 0.333333;
            turf_diameter = diameter * 0.333333;                             
            turf_height = height * 0.333333;    
			turf_widthofbase = widthofbase * 0.333333;    	
			area_length = length / 3.2808;
            area_width = width / 3.2808; 
			area_diameter = diameter / 3.2808;
			area_height = height / 3.2808;
			area_widthofbase = widthofbase / 3.2808;
            area_depth = (depth == 0 ? 0 : (depth / 39.370)); 
        }
        
        if (units == 'yards') {
            turf_length = length;
            turf_width = width;
            turf_diameter = diameter;                            
            turf_height = height;    
			turf_widthofbase = widthofbase; 
            area_length = length * 0.9144;
            area_width = width * 0.9144; 
			area_diameter = diameter * 0.9144;
			area_height = height * 0.9144;
			area_widthofbase = widthofbase * 0.9144;
            area_depth = (depth == 0 ? 0 : (depth / 39.370));     
        }        

        if (shape == 'square') {
            turf_squared = (turf_length * turf_width).toFixed(2); 
			area_squared = (area_length * area_width);    
            area_cubed = (area_length * area_width * area_depth).toFixed(2);
			
        }
        
        if (shape == 'triangle') {
            turf_squared = ((turf_height * turf_widthofbase)*(0.5)).toFixed(2);
            area_squared = ((area_height * area_widthofbase)*(0.5)).toFixed(2);
			area_cubed = (((area_height * area_widthofbase)*(0.5)) * area_depth).toFixed(2);
        }

        if (shape == 'circle') {
            turf_squared = (((turf_diameter / 2) * (turf_diameter / 2) * Math.PI)).toFixed(2);
			area_squared = ((area_diameter / 2) * (area_diameter / 2) * Math.PI);
			area_cubed = (Math.PI * area_depth * (area_diameter / 2) * (area_diameter / 2)).toFixed(2);
        }

        if ( area_squared == '0.00' || isNaN( area_squared ) ) {
            $('.calculator-results').promise().done(function(){
                $('.turf-result').html('--');
                $('.soil-result').html('--');
                $('.mbc-result').html('--');
                $('.top-dressing-result').html('--');
                $('.fertiliser-result').html('--');
                $('.turf-notice').html('');
                $('.calculator-results').fadeIn("slow"); 
            });
            return false;
        } 
        
        $('.calculator-results').promise().done(function(){
            $('.turf-result').html(Math.ceil(turf_squared) + ' Rolls<br/>' + turf_squared + '&#40;yd&sup2;&#41;');
            $('.soil-result').html((area_cubed * 1.7).toFixed(2) + ' tonnes');
            $('.mbc-result').html(area_cubed + 'm&sup3<br/>');
            $('.top-dressing-result').html(((area_squared * 0.005) * 1.7).toFixed(2) + ' tonnes');
            $('.fertiliser-result').html((area_squared * 0.035).toFixed(2) + 'kg<br/>' + (Math.ceil((area_squared * 0.035)) <= 15 ? Math.ceil((area_squared * 0.035)/5) + ' x 5kg tubs' : Math.ceil((area_squared * 0.035)/25) + ' x 25kg bags') );
            $('.turf-notice').html('We recommend an extra 5&#37; of turf to account for off cuts, using the calculation above this would equate to ' + Math.ceil((turf_squared/100)*5) + (Math.ceil((turf_squared/100)*5) == 1 ? ' roll' : ' rolls') + ' of extra turf.');
            $('.calculator-results').fadeIn("slow");            
        });   
        
    });
});

